@@ -18,13 +18,13 @@ Example Usage::
     alicePhone.type = 'mobile'
 
     f = open('example.bin', 'w')
-    addresses.writeTo(f)
+    addresses.write(f)
     f.close()
 
     # Reading
     f = open('example.bin')
 
-    addresses = addressbook.AddressBook.readFrom(f)
+    addresses = addressbook.AddressBook.read(f)
 
     for person in addresses.people:
         print(person.name, ':', person.email)
@@ -32,8 +32,7 @@ Example Usage::
             print(phone.type, ':', phone.number)
 """
 from .version import version as __version__
-from .capnp import *
-from .capnp import _DynamicStructReader, _DynamicStructBuilder, _DynamicResizableListBuilder, _DynamicListReader, _DynamicListBuilder, _DynamicOrphan, _DynamicResizableListBuilder, _MallocMessageBuilder, _PackedFdMessageReader, _StreamFdMessageReader, _write_message_to_fd, _write_packed_message_to_fd
-del capnp
+from .lib.capnp import *
+from .lib.capnp import _DynamicStructReader, _DynamicStructBuilder, _DynamicResizableListBuilder, _DynamicListReader, _DynamicListBuilder, _DynamicOrphan, _DynamicResizableListBuilder, _MallocMessageBuilder, _PackedFdMessageReader, _StreamFdMessageReader, _write_message_to_fd, _write_packed_message_to_fd, _StructModule, _InterfaceModule, _DynamicCapabilityClient, _CapabilityClient, _EventLoop
 
 add_import_hook() # enable import hook by default
